@@ -25,6 +25,7 @@ from source.pipeline.commands import pipeline as pipeline_group
 from source.workflow.commands import wf as workflow_group
 from source.template.commands import template as template_group
 from source.dataset.commands import dataset as dataset_group
+from source.datastream.commands import datastream as datastream_group
 from source.org.commands import org as org_group
 from source.access.commands import access as access_group
 from source.graph.commands import graph as graph_group
@@ -59,6 +60,7 @@ cli.add_command(pipeline_group)
 cli.add_command(workflow_group)
 cli.add_command(template_group)
 cli.add_command(dataset_group)
+cli.add_command(datastream_group)
 cli.add_command(org_group)
 cli.add_command(access_group)
 cli.add_command(graph_group)
